Mise à jour en cours...
Mise à jour reussi...
Echec mise à jour...
mesures

1 | Surchauffe | 10.9 | °
2 | Delta mesuré | 3.9 | °
3 | Delta maxi | 16.6 | °
4 | Delta moyen | 3.9 | °
5 | Puissance moyenne | 0.0 | kW
6 | Puissance calorifique | 0.0 | kW
7 | Puissance compresseur | 0.0 | W
8 | COP | 0.0 |
11 | Delta chauffage | 0.0 | °
12 | Delta capteur | -0.7 | °
15 | Puissance accessoires | 0.0 | W
16 | Puissance absorbée | 283.6 | kWh
17 | Puissance absorbée | 2.0 | MWh
19 | Nombre Démarrages | 2856.0 |
20 | Conso divers T1 | 0.4 | kWh
21 | Conso chauffage T1 | 12.8 | kWh
22 | Conso Rafraichissement T1 | 0.0 | kWh
25 | Conso dégivrage T1 | 0.1 | kWh
26 | Conso total T1 | 13.3 | kWh
27 | Conso compteur 1 T1 | 0.0 | kWh
28 | Conso compteur 2 T1 | 0.0 | kWh
29 | Conso compteur 3 T1 | 0.0 | kWh
30 | Conso divers T2 | 55.1 | kWh
31 | Conso chauffage T2 | 2172.7 | kWh
32 | Conso rafraichissement T2 | 0.0 | kWh
35 | Conso dégivrage T2 | 22.1 | kWh
36 | Conso total T2 | 2249.9 | kWh
37 | Conso compteur 1 T2 | 0.0 | kWh
38 | Conso compteur 2 T2 | 0.0 | kWh
39 | Conso compteur 3 T2 | 0.0 | kWh
40 | Conso divers T3 | 0.0 | kWh
41 | Conso chauffage T3 | 0.1 | kWh
42 | Conso rafraichissement T3 | 0.0 | kWh
45 | Conso dégivrage T3 | 0.0 | kWh
46 | Conso total T3 | 0.1 | kWh
47 | Conso compteur 1 T3 | 0.0 | kWh
48 | Conso compteur 2 T3 | 0.0 | kWh
49 | Conso compteur 3 T3 | 0.0 | kWh
50 | Heures divers T1 | 0.0 | h
51 | Heures chauffage T1 | 4.8 | h
52 | Heures rafraichissement T1 | 0.0 | h
55 | Heures dégivrage T1 | 0.1 | h
56 | Heures total T1 | 4.8 | h
57 | Heures appoint T1 | 0.0 | h
60 | Heures divers T2 | 0.0 | h
61 | Heures chauffage T2 | 1035.2 | h
62 | Heures rafraichissement T2 | 0.0 | h
65 | Heures dégivrage T2 | 12.8 | h
66 | Heures total T2 | 1048.2 | h
67 | Heures appoint T2 | 0.0 | h
70 | Heures divers T3 | 0.0 | h
71 | Heures chauffage T3 | 0.0 | h
72 | Heures rafraichissement T3 | 0.0 | h
75 | Heures dégivrage T3 | 0.0 | h
76 | Heures total T3 | 0.0 | h
77 | Heures appoint T3 | 0.0 | h
100 | u(t) | 0.0 | zorg
99 | boot | 21.0 |